# Changelog

### v0.1.0
 - initial release

### v0.1.2
 - fix explanation exporting in json
 
### v0.1.3
 - add Toulmin visualizer
 
### v0.1.4
 - add latent continuous target
 - complement documentation

### v0.1.5
 - fix critical error with error checking
 - add json exported pretty-print option

### v0.1.6
 - fix data types of openml features in examples
 
### v0.1.7
 - fix data types of openml features in one example
 - fix key names of labels of latent continuous target
 - bump argueview-js version to 0.3.1
 - finalize feature list visualizer
 
### v0.1.8
 - added support for omitting features in the FeatureListVisualizer.
